monkey.ci.plugin.github

Provides functions for interacting with the Github API from a MonkeyCI build

Provides functions for interacting with the Github API from a MonkeyCI build
raw docstring

create-release!clj

(create-release! c {:keys [org repo tag name desc target]})

Creates a new release for the repository identified by org and repo. The tag specifies the tag to use for the release, or, if it does not exist, to create. In the latter case, a target commitish should be given on which to create the tag. If not given, the default branch is used. An additional name and desc are used for extra information. Returns the http result, should be status 201 if successful.

Creates a new release for the repository identified by `org` and `repo`.
The `tag` specifies the tag to use for the release, or, if it does not
exist, to create.  In the latter case, a `target` commitish should be
given on which to create the tag.  If not given, the default branch is 
used.  An additional `name` and `desc` are used for extra information.
Returns the http result, should be status 201 if successful.
sourceraw docstring

format-tagclj

(format-tag tag {:keys [name-format] :or {name-format "v%s"}})
source

github-jobclj

(github-job token f)

Template that invokes a target fn using a github client created from context.

Template that invokes a target fn using a github client created from context.
sourceraw docstring

make-changesetclj

(make-changeset c {:keys [org repo branch]})
source

make-clientclj

Creates a new Github api client. You can pass in a token, or api key with secret.

Creates a new Github api client.  You can pass in a token, or api key with secret.
sourceraw docstring

parse-urlclj

(parse-url git-url)

Parses git url to extract org and repo

Parses git url to extract org and repo
sourceraw docstring

patch-fileclj

(patch-file client opts f & args)

Patches file indicated by given location by applying f to it with arguments. A new commit is created on the specific branch with the given commit msg.

Patches file indicated by given location by applying `f` to it with arguments.
A new commit is created on the specific branch with the given commit msg.
sourceraw docstring

patch-filesclj

(patch-files client {:keys [commit-msg patches] :as opts})

Patches multiple files, as indiciated in the patches option. Each patch contains a path and a patcher fn, which receives the file contents and returns updated contents. A single commit is created for the combined patches.

Patches multiple files, as indiciated in the `patches` option.  Each patch
contains a `path` and a `patcher` fn, which receives the file contents and
returns updated contents.  A single commit is created for the combined 
patches.
sourceraw docstring

patch-jobclj

(patch-job {:keys [job-id token org repo branch]
            :or {job-id "patch" branch "main"}
            :as opts})

Creates a job that patches one or more files in a Github repo. Either a path and a patcher is given, or multiple patches are specified. The patcher functions receive the file contents as argument, and are expected to return the new file contents.

Creates a job that patches one or more files in a Github repo.  Either a
`path` and a `patcher` is given, or multiple `patches` are specified. The
 patcher functions receive the file contents as argument, and are expected
 to return the new file contents.
sourceraw docstring

release-jobclj

(release-job & [{:keys [token] :as config}])

Returns a fn that will in turn create a release job, if the conditions are met. By default a release will be created if the build is triggered from a tag, and the tag name is used to format the release name. Note that either a :token must be specified, or a github-token build param must be provided.

Returns a fn that will in turn create a release job, if the conditions are met.
By default a release will be created if the build is triggered from a tag, and
the tag name is used to format the release name.  Note that either a `:token`
must be specified, or a `github-token` build param must be provided.
sourceraw docstring

token-paramclj

source

cljdoc builds & hosts documentation for Clojure/Script libraries